package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CouponUser;
import com.ruoyi.system.service.ICouponUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 优惠券领取记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/CouponUser")
public class CouponUserController extends BaseController
{
    @Autowired
    private ICouponUserService couponUserService;

    /**
     * 查询优惠券领取记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:CouponUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(CouponUser couponUser)
    {
        startPage();
        List<CouponUser> list = couponUserService.selectCouponUserList(couponUser);

        return getDataTable(list);
    }

    /**
     * 导出优惠券领取记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:CouponUser:export')")
    @Log(title = "优惠券领取记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CouponUser couponUser)
    {
        List<CouponUser> list = couponUserService.selectCouponUserList(couponUser);
        ExcelUtil<CouponUser> util = new ExcelUtil<CouponUser>(CouponUser.class);
        util.exportExcel(response, list, "优惠券领取记录数据");
    }

    /**
     * 获取优惠券领取记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:CouponUser:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(couponUserService.selectCouponUserById(id));
    }

    /**
     * 新增优惠券领取记录
     */
    @PreAuthorize("@ss.hasPermi('system:CouponUser:add')")
    @Log(title = "优惠券领取记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CouponUser couponUser)
    {
        return toAjax(couponUserService.insertCouponUser(couponUser));
    }

    /**
     * 修改优惠券领取记录
     */
    @PreAuthorize("@ss.hasPermi('system:CouponUser:edit')")
    @Log(title = "优惠券领取记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CouponUser couponUser)
    {
        return toAjax(couponUserService.updateCouponUser(couponUser));
    }

    /**
     * 删除优惠券领取记录
     */
    @PreAuthorize("@ss.hasPermi('system:CouponUser:remove')")
    @Log(title = "优惠券领取记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(couponUserService.deleteCouponUserByIds(ids));
    }
}
